#!/bin/sh

CFG_DIR=$HOME/.gngeo-gui
CFG_FILE=$CFG_DIR/gngeo-gui.cfg
mkdir -p $CFG_DIR 2> /dev/null
if [ ! -r $CFG_FILE ]
then
	echo "exec_path /opt/gngeo/bin" > $CFG_FILE
fi
cd /opt/gngeo-gui/
python gngeo-gui.py > $CFG_DIR/gngeo-output.log
